/*
*******************************************************************************************************************
*								Demonstration for using UART module built-in 16F690
* Description:  This program demonstrates simple UART function.
*				The PCB employed was nRF_CB_Eval_1a.
*				Computer nowadays may not have a COM PORT for RS232 data communication. USB port is taking its
*				place now. The CP2102(www.silabs.com) onboard is a single-chip USB to UART bridge that converts 
*				data traffic between USB and UART formats.
*				This program simply echoes any character received from a PC's USB port output by any RS232
*				program such as Docklight (www.docklight.de) or HyperTerminal. A virtual COM PORT would be created
*				by the Silabs driver and hence it is possible to use a USB port like a COM PORT in the past.
*				The advantage is that, we don't need to change our embedded software that has been built for 
*				UART communication for nowadays PC USB port. The baud rate is 9600bps, 8-N-1.
* File:			..\uartDemo1\main.c
* Software:		HiTech PICC Lite compiler version 9.60 under MPLAB IDE v7.50
* Programmer: 	John Leung, TechToys Co. (www.TechToys.com.hk)
* Hardware:		nRF_CB_Eval_1a, at Vdd=3.0V powered by USB 5V, internal regulator of Silabs CP2102 USB<->UART bridge
* Date:			28th April 2007
* Version:		1.0
*
*******************************************************************************************************************
*/

#include <stdio.h>
#include <pic.h>
#include "uart.h"

/*
********************************************************************************************************************
*												Configuration Bit Section
*
* Configuration bit setting for 16F690 : Internal OSC with no clock out, watchdog disabled, etc.
* Please consult \\HI-TECH Software\PICC\lite\9.60\include\pic16f685.h for meaning of the arguments.
********************************************************************************************************************
*/
__CONFIG(INTIO&WDTDIS&PWRTDIS&MCLREN&UNPROTECT&BORDIS&IESODIS&FCMDIS);


/*
********************************************************************************************************************
* 													Main
* A simple demonstration of serial communications which
* incorporates the on-board hardware USART of the Microchip
* PIC16Fxxx series of devices.
********************************************************************************************************************
*/
void main(void){
	unsigned char input;
	ANSEL = 0x00;
	ANSELH = 0x00;	//all digital operation
	SCS = 1;		//internal oscillator is used for system clock and 
					//accept the deafulat clock speed of 4MHz defined by
					//IRCF<2:0>=110
	INTCON=0;		// purpose of disabling the interrupts.

	init_comms();	// set up the USART - settings defined in usart.h

	// Output a message to prompt the user for a keypress	
	printf("\rPress a key and I will echo it back:\n");
	while(1){
		input = getch();	// read a response from the user
		printf("\rI detected [%c]",input);	// echo it back
	}
}
